function animate3d_nbars(x_coordinates, y_coordinates, z_coordinates)
%        3D animation of any number of connected bars
% When given the lists x_coordinates=[xA, xB, xC, etc], y_coordinates(yA, yB, yC, etc),
% and z_coordinates(zA, zB, zC, etc) 
% of the the x-y-z coordinates of several points A, B, C, etc, a call to the function 
% animate3d_nbars.m generates a set of straight lines by connecting the points in the  
% given sequence A, B, C, etc, with a black dot at each point. Thus a call such as 
% animate3d_nbars([xA, xB, xC], [yA, yB, yC], [zA, zB, zC]), typed in the Matlab command 
% window, creates a figure window with two lines AB and BC, with black dots at the ends  
% of each line. When xA, xB, xC, etc; yA, yB, yC, etc; and zA, zB, zC, etc, are n by m 
% arrays an animation is displayed.
%  This function is called by top_dynamics.m and two_particles_table.m 
% to animate the 3D motion. See those programs and run them to watch the motion. 

% *****************************************************************************************
% NOTE: Comment out this part if you don't want to see this message after you get used to it
disp(' '); disp('  =====>  IMPORTANT MESSAGE:  <=====')
disp(' IF THE SIMULATION RUNS EITHER TOO FAST OR TOO SLOW IN YOUR COMPUTER,')
disp(' change the time_step in the time array t=[t0:time_step:tfinal] of your simulation ')
disp(' ---> EITHER to a smaller value to slow down the animation ')
disp(' ---> OR to a larger value to speed up the animation')
% *****************************************************************************************

[number_of_time_points, len]=size(x_coordinates); 

% minimum and maximum value of x_coordinates, y_coordinates, and z_coordinates:
xcoord_min=min(min(x_coordinates));  xcoord_max=max(max(x_coordinates));   
ycoord_min=min(min(y_coordinates));  ycoord_max=max(max(y_coordinates));
zcoord_min=min(min(z_coordinates));  zcoord_max=max(max(z_coordinates));

% Create a figure for the animation, first deleting it, if it exists 
% (to prevent new plots to be superimposed in the same window) 
delete( findobj('type','figure','name', 'Animation window') )
% Start by determining the computer monitor size so that the animation window  
% is properly placed and sized in any computer screen. 
screen_width_and_height=get(0,'screensize');     %  width and height of the screen, in pixels
PC_screen_width =screen_width_and_height(3);     % this is the width of the computer monitor
PC_screen_height=screen_width_and_height(4);     % this is the height of the computer monitor

x_topleft= 0.65*PC_screen_width;   % choice for the top left x-coordinate of the figure window
y_topleft= 0.17*PC_screen_height;  % choice for the top left y-coordinate of the figure window
top_left_coordinates=[x_topleft, y_topleft]; 
size_of_fig_window = [0.32*PC_screen_width, 0.47*PC_screen_height];  
% the above are the width and height chosen for the animation window
% Now, create the figure window.  
fig=figure( 'position', [x_topleft, y_topleft,size_of_fig_window(1), size_of_fig_window(2)], 'name','Animation window', 'color', 'white');

azimuth=-240; elevation=30;  % these are the azimuth (from the -y axis) and elevation 
% (from the xy plane) viewing angles in degrees
fig_axis = axes('Xlim', [xcoord_min,  xcoord_max], 'Ylim', [ycoord_min,  ycoord_max], 'Zlim', [zcoord_min,  zcoord_max], 'dataaspectratio', [1, 1, 1], 'NextPlot','add', 'View', [azimuth, elevation], 'box', 'on');  
anim=plot3([0 0 0], [0 0 0], [0 0 0], 'linewidth', 2,  'marker', '.', 'markersize', 40, 'MarkerFaceColor', 'black', 'EraseMode','xor');
xlabel('x'); ylabel('y')

for itime=1:number_of_time_points   % this is the animation loop
  set(anim,'xdata', x_coordinates(itime,:),  'ydata', y_coordinates(itime,:), 'zdata', z_coordinates(itime,:) );            
  drawnow; 
end        
% end of the file animate3d_nbars.m
