function output = boomerang(t, g,  x0, xdot0, y0)
% Example 7.9.1; using the state variables var(1)=x, var2=dx/dt, var(3)=y
% Example of usage [ using the initial conditions x(0)=0, dx_dt(0)=5*cos(pi/6),  y(0)=0 ] 
% my_output = boomerang([0:0.002:6], 9.81,  0, 5*cos(pi/6), 0);

initial_conditions=[x0, xdot0, y0];
[t, y]=ode45(@rhs_of_diff_eqs, t, initial_conditions, [], g);   
output=[t, y];             
% output is a n by 4 matrix, where n=length(t) is the number of points in the array t
% column 1: t, column 2: x, column 3: dx/dt; column 4: y

x=output(:,2); y=output(:,4);

close all; % close (i.e., delete) all figure windows
figure('color', 'white');  plot(t, x,  t, y, '--');  grid;     % plot of x and y versus t
xlabel('t', 'fontsize', 12);    ylabel('solid line: x   ;   dashed line: y', 'fontsize', 12); 
title('Example 7.9.1','fontsize', 12);

figure('color', 'white');  plot(x, y);  grid        % plot of y versus x
xlabel('x', 'fontsize', 12);  ylabel('y', 'fontsize', 12);  title('Example 7.9.1','fontsize', 12);
  
animate_nbars(x, y);     % this call animates the motion

function dvar_dt=rhs_of_diff_eqs(t, var, g) 
% Note:  var(1)=x, var(2)=d(x)/dt, var(3)=y;  The diff. eqs. are Eqs. (7.9.1j) and (7.9.1i) 
   f1=0.5*sin(t);  df1_dt=0.5*cos(t);    f2=5*sin(pi/6)-0.85*t;  df2_dt=-0.85; 
   dvar_dt=[var(2); -(var(2)*df1_dt+df2_dt+g)*f1/(1+f1^2); f1*var(2)+f2];
   
% end of the file boomerang.m