function output=example6_7_1(tau, omegasqL_over_g, R_over_L, theta_0, thetadot_0)
% Example 6.7.1 analyzed in Section 6.7
% Example of usage ( using the initial conditions theta_0=30*pi/180 rad, thetadot_0=0 ):  
% my_output = example6_7_1([0:0.1:10], 1.5, 1/3, 30*pi/180, 0);

initial_conditions=[theta_0; thetadot_0];
[tau, y]=ode45(@rhs_of_diff_eqs, tau, initial_conditions, [ ], omegasqL_over_g, R_over_L); 
output=[tau, y];
% output is a n by 3 matrix, where n is the number of points in the array tau
% column 1: tau;  column 2: theta;  column 3: d(theta)/d(tau) 
theta=output(:,2); dtheta_dtau=output(:,3); cos_theta=cos(theta); sin_theta=sin(theta);

% Normalized omponents A1, A2, and A3 of the reaction force at point A:
 A1=-cos_theta-(dtheta_dtau.^2)/2-omegasqL_over_g*(R_over_L+sin_theta/2).*sin_theta;
 A2=sqrt(omegasqL_over_g)*dtheta_dtau.*cos_theta;
 A3=(sin_theta-R_over_L*omegasqL_over_g*cos_theta)/4;
% Magnitude of the normalized reaction force and moment at point A: 
 reaction_force_at_A  = sqrt(A1.^2+A2.^2+A3.^2);   reaction_moment_at_A = 2*A2/3;

% Plots:
 close all  % closing (i.e., deleting) all existing figures
 figure('color', 'white'); plot(tau, theta*180/pi);   grid     
 xlabel(['Nondimensional time ', '\tau'], 'fontsize', 12), ylabel(['\theta', ' (degrees)'], 'fontsize', 12)

 figure('color', 'white');  plot(tau, reaction_force_at_A); grid     
 xlabel(['Nondimensional time ', '\tau'], 'fontsize', 12) 
 ylabel('(A^2_1+A^2_2+A^2_3)^{1/2}/(mg)', 'fontsize', 12)

 figure('color', 'white');  plot(tau, reaction_moment_at_A), grid     
 xlabel(['Nondimensional time ', '\tau'], 'fontsize', 12),   ylabel('M_3/(mgL)', 'fontsize', 12)
 
 function dy_dtau=rhs_of_diff_eqs(tau, y, omegasqL_over_g, R_over_L)
  % Note:  y(1)=theta, y(2)=d(theta)/d(tau), where tau=t*sqrt(g/L)
  sin_theta=sin(y(1));
  dy_dtau(1)=y(2);     % the next expression is d2x_dt2 from Eq. (6.7.1q) with b=0 
  dy_dtau(2)=(3*R_over_L/2+sin_theta)*omegasqL_over_g*cos(y(1))-3*sin_theta/2;
  dy_dtau=[dy_dtau(1); dy_dtau(2)];
  
% end of the file example6_7_1
