function output = fourbar_mechanism(t, L1, L2, L3, L4, theta2, dtheta2_dt, d2theta2_dt2, solution_number)
% Animation of the four-bar mechanism in Section 3.2
% Example of usage [copy the next three lines, without the %, to the Matlab command window]:
% t=[0:0.001:5]; theta2=pi/6+1.5*pi*sin(2*t); dtheta2_dt=3*pi*cos(2*t); d2theta2_dt2=-6*pi*sin(2*t);
% my_output=fourbar_mechanism(t, 1, 0.45, 0.8, 0.7, theta2,  dtheta2_dt, d2theta2_dt2, 1);
%   NOTE: any name can be used for the variable to the left of the equal sign in line 1
%
% To slow down the animation, choose a smaller time step for the input array t  
% Conversely, to speed up the animation, choose a larger time step 
% For example, the array t=[0:0.001:5] yields a slower animation than the array t=[0:0.01:5] 
%
% IN ADDITION TO ANIMATING THE MECHANISM, SUCH A CALL TO THE FUNCTION fourbar_mechanism.m 
% GENERATES A len (WHERE len IS THE NUMBER OF POINTS IN THE ARRAY t) BY 10 MATRIX CALLED 
% my_output, WHOSE COLUMNS ARE   t, theta2, theta3, theta4, dtheta2_dt, dtheta3_dt, 
% dtheta4_dt, d2theta2_dt2, d2theta3_dt2, d2theta4_dt2
% my_output(:,3), my_output(:,4)*180/pi, FOR EXAMPLE, GIVE theta3 AND theta4 (IN DEGREES).
%  TO PLOT theta4 VERSUS TIME t, FOR EXAMPLE, TYPE, IN THE MATLAB COMMAND WINDOW, 
% THE COMMANDS          figure(); plot(my_output(:,1), my_output(:,4)*180/(2*pi) )
% To put a grid on the plot, type   grid
    
disp(' ')
disp(' MESSAGE FROM THE FUNCTION fourbar_mechanism.m:')    
disp('IN ADDITION TO ANIMATING THE MECHANISM, A CALL TO THE FUNCTION fourbar_mechanism')
disp('RETURNS 10 COLUMNS CONTAINING t, theta2, theta3, theta4, dtheta2_dt, dtheta3_dt, ')
disp('  dtheta4_dt, d2theta2_dt2, d2theta3_dt2, d2theta4_dt2')

 output = fourbar_kinematics(t, L1, L2, L3, L4, theta2, dtheta2_dt, d2theta2_dt2, solution_number);
 theta2=output(:,2);  theta4=output(:,4);  
 len=length(t);  temp=ones(len,1);
 xA= zeros(len,1); yA=xA;  xB=L2*cos(theta2);  yB=L2*sin(theta2);   % points A and B of bar AB
 xC=L1+L4*cos(theta4);  yC=L4*sin(theta4);      % point C of bar BC        
 xD=L1*temp;  yD=yA;     % point D

 close all  % deleting all existing figures
 x_coordinates=[xA, xB, xC, xD]; y_coordinates=[yA, yB, yC, yD]; 
 animate_nbars(x_coordinates, y_coordinates)   % ANIMATION (done by the program animate_nbars)
% end of the file fourbar_mechanism.m