function output = ballistics(t, d2x_dt2, d2y_dt2,  x_0, dotx_0, y_0, doty_0) 
// Exammple 2.5.8
// Example of usage: 
// my_output = ballistics([0:0.01:2.5], 0, -9.81,0, 10, 0, 10);

function dvar_dt=rhs_of_diff_eqs(t, var) 
    // Note:  var(1)=x, var(2)=dx/dt, var(3)=y, var(4)=dy/dt
    dvar_dt(1)= var(2),    // this is dx/dt     
    dvar_dt(2)= d2x_dt2    // this is d2(x)/dt2  
    dvar_dt(3)= var(4)     // this is dy/dt 
    dvar_dt(4)= d2y_dt2 // this is d2(y)/dt2  
endfunction

initial_conditions=[x_0; dotx_0; y_0; doty_0];
state_variables=ode(initial_conditions, 0, t, rhs_of_diff_eqs)
output=[t', state_variables']   
       // output is a n by 5 matrix, where n is the number of points in the array t; 
       // column 1: t, column 2: x, column 3: dx/dt, column 4: y, column 5: dy/dt

disp('NOTE: The output of a call to the function ballistics.sci is a n by 5 matrix, ')
disp('where n is the number of points in the time array t')
disp('1st column: t, 2nd column: x, 3rd column: dx/dt, 4th column: y, 5th column: dy/dt')

xdel(winsid( ))  // this command deletes all existing figures
x_coordinates=output(:,2); y_coordinates=output(:,4);
animate_nbars(x_coordinates, y_coordinates)   // Animation  (the "bar" will be a point)
endfunction      // end of the file ballistics.sci
