function output=foucault_pendulum(t, omega_times_sin_lambda, g_over_L, x_0, xdot_0, y_0, ydot_0)
// Animation of the Foucault pendulum analyzed in Chapter 8
// Example of usage [using the initial conditions  x(0)=0.01; x_dot(0) =0; y(0)=0; y_dot(0)=0 ]:
// my_output = foucault_pendulum([0:0.01:30], 0.0727, 0.981, 0.01, 0,  0, 0);

disp('  NOTE: THE FUNCTION foucault_pendulum RETURNS 5 COLUMNS WITH t, x, dx/dt, y, and dy/dt:')

function dy_dt=rhs_of_diff_eqs(t, y) 
    // Note:  y(1)=x, y(2)=dx/dt, y(3)=y, y(4)=dy/dt
  dy_dt(1)=y(2)   
  dy_dt(2)=2*omega_times_sin_lambda*y(4)-g_over_L*y(1)    // this is d2x/dt2
  dy_dt(3)=y(4)  
  dy_dt(4)=-2*omega_times_sin_lambda*y(2)-g_over_L*y(3)   // this is d2y/dt2
endfunction

initial_conditions=[x_0; xdot_0; y_0; ydot_0];
state_variables=ode(initial_conditions, 0, t, rhs_of_diff_eqs)
output=[t', state_variables']    // ' is the transpose operator
// The variable output is a n by 5 matrix, where n is the number of points in the array t
// column 1: t, column 2: x, column 3: dx/dt; column 4: y; column 5: dy/dt

x=output(:,2), y=output(:,4)

xdel(winsid())  // deleting all existing figures
figure('background', 8);  plot(x,y),  xgrid // plot of y versus x
xlabel('x', 'fontsize', 3), ylabel('y', 'fontsize', 3)
title('Foucault pendulum path','fontsize', 3)
   
 animate_nbars(x, y)        // ANIMATION:
endfunction      // end of the file foucault_pendulum.sci


