function output=inclined_plane(t, m1_over_m2, k_over_m2, c2_over_m2, c1_over_m2, alpha, g, Lu, x_0, xdot_0, r_0, rdot_0)
// Animation for Example 2.5.9. The animation draws five bars, AB, BC, AC,, CD, and DE,    
// each one with a small dot at their ends. 
// Example of usage ( using the initial conditions  x(0)=1; xdot(0)=0; r(0)=2; rdot(0)=0 )
// my_output = inclined_plane([0:0.01:20], 0.1,  5, 0, 0, %pi/4, 9.81, 1, 1, 0,  2, 0);

sin_alpha=sin(alpha), cos_alpha=cos(alpha), temp=m1_over_m2+sin_alpha^2

function dy_dt=rhs_of_diff_eqs(t, y) 
    // Note:  y(1)=x, y(2)=dx/dt, y(3)=r, y(4)=dr/dt
  dy_dt(1)=y(2),     // the expression in the next line is d2(x)/dt2 from Eq. (2.5.9i)
  dy_dt(2)=  ( (c2_over_m2*y(4)+k_over_m2*(y(3)-Lu))*cos_alpha-g*sin_alpha*cos(alpha) -c1_over_m2*y(2) )/temp   
  dy_dt(3)=y(4),  // the following expression is d2(r)/dt2 from Eq. (2.5.9j)
  dy_dt(4)=( c1_over_m2*cos_alpha*y(2)+(1+m1_over_m2)*( g*sin_alpha-(c2_over_m2*y(4)+ k_over_m2*(y(3)-Lu)) ) ) 
endfunction

initial_conditions=[x_0; xdot_0; r_0; rdot_0]
state_variables=ode(initial_conditions, 0, t, rhs_of_diff_eqs) 
  
output= [t', state_variables']    // ' is the transpose operator
    // this is a len by 5 matrix, where len is the number of points in the array t
    // column 1: t,  column 2: x, column 3: dx/dt; column 4: r; column 5: dr/dt

// ANIMATION: 
len=length(t)   // this is the number of points in the array t 
x=output(:,2), r=output(:,4)   // these are len by 1 columns 
col_of_ones=ones(len,1) 
xA=x, yA=zeros(len,1), xB=x+3, yB=yA,   xC=x,  yC=3*tan(alpha)*col_of_ones 
xD=x+0.05*sin_alpha,  yD=(3*tan(alpha)+0.05*cos(alpha))*col_of_ones, xE=xD+r*cos(alpha), yE=yD-r*sin_alpha 
x_coordinates=[xC, xA, xB, xC, xD, xE];  y_coordinates=[yC, yA, yB, yC, yD, yE] 
 
// Delete all figures, and call the fnction animate_nbars
xdel(winsid());  animate_nbars(x_coordinates, y_coordinates) 
endfunction      // end of the file inclined_plane.sci
