function output = scotch_yoke(t, R, theta, dtheta_dt, d2theta_dt2)
// Animation of the Scotch yoke mechanism in Section 3.5 
// Example of usage  [copy the next two lines, without the //, to the Scilab console]:
// t=[0:0.01:10]; theta=%pi/2+2*t; dtheta_dt=2; d2theta_dt2=0; 
// my_output=scotch_yoke(t, 1, theta, dtheta_dt, d2theta_dt2);
//
// To slown down the animation, choose a smaller time step for the input array t  
// Conversely, to speed up the animation, choose a larger time step  
// For example, the array t=[0:0.01:5] yields a slower animation than the array t=[0:0.1:5] 
//
// IN ADDITION TO ANIMATING THE MECHANISM, SUCH A CALL TO THE FUNCTION  
// scotch_yoke.sci GENERATES A len (WHERE len IS THE NUMBER OF POINTS IN THE   
// ARRAY t) BY 4 MATRIX CALLED my_output, WHOSE COLUMNS ARE  time t, theta, dxA_dt, d2xA_dt2
//  my_output(:,3), FOR EXAMPLE, GIVES dxA_dt. TO PLOT IT, TYPE, IN THE SCILAB CONSOLE, 
//  THE COMMANDS   figure(); plot( output(:,1}), my_output(:,3) )
// To put a grid on the plot, type   xgrid

disp('NOTE: IN ADDITION TO ANIMATING THE SCOTCH YOKE MECHANISM, THIS FUNCTION ') 
disp(' RETURNS 4 COLUMNS CONTAINING t, theta, d(xA)/dt, d2(xA)/dt2')

// Make sure that theta, dtheta_dt, and d2theta_dt2 have the same length as t
len=length(t);  temp=ones(1,len); 
theta=theta.*temp; dtheta_dt=dtheta_dt.*temp; d2theta_dt2=d2theta_dt2.*temp;

sin_theta = sin(theta);    cos_theta = cos(theta);
xO=zeros(len,1),  xP=R*cos_theta';  xB=xP;   xC=xP
yO=xO,  yP=R*sin_theta',  yB=1.5*R*ones(len,1),  yC=-yB

xdel(winsid());   // deleting all figures 
x=[xO, xP, xB, xC],   y=[yO, yP, yB, yC],  animate_nbars(x, y) // this animates the motion

// Velocity dxA_dt=d(xA)/dt  and acceleration d2xA_dt2=d2(xA)/dt2, where xA=R*cos(theta):
  dxA_dt=-R*dtheta_dt.*sin_theta; d2xA_dt2=-R*(d2theta_dt2.*sin_theta+(dtheta_dt.^2).*cos_theta); 
  
  output = [t; theta; dxA_dt; d2xA_dt2]'; 
endfunction      // end of the file scotch_yoke.sci
