function output = sim_model_ex5_3_11(tau, L2_over_L1, xdoubledot_over_g, Mbar_over_mgL1, cstar, theta_0, thetaprime_0)
// Example 5.3.11 in Chapter 5: tau=t*sqrt(g/L1), Mbar_over_mgL1=mbar/(m*g*L1), 
// and cstar=c/(m*L1*sqrt(g*L1))
// Example of usage ( using the initial conditions  theta_0=90*%pi/180; thetaprime_0=0 ):
// tau=[0:0.005:10]; xdoubledot_over_g=-2;  Mbar_over_mgL1=0;  
// my_output = sim_model_ex5_3_11(tau,2, xdoubledot_over_g, Mbar_over_mgL1, 0, 90*%pi/180, 0);

disp('NOTE: IN ADDITION TO ANIMATING THE PENDULUM ANALYZED IN EXAMPLE 5.3.11,')
disp('AND PLOTTING theta versus time tau, A CALL TO THE FUNCTION sim_model_ex5_3_11,')  
disp(' AS EXEMPLIFIED IN THE FIRST 5 COMMENT LINES OF THIS FUNCTION,') 
disp(' RETURNS 3 COLUMNS CONTAINING  tau, theta, and d(theta)/dtau')
disp('TO PLOT d(theta)/dtau VERSUS theta, FOR EXAMPLE, USE THE COMMANDS:')
disp('       figure(); plot(my_output(:,2), my_output(:,3)) ')
disp('   To put a grid on the plot, type  xgrid ')

function dy_dtau=rhs_of_diff_eqs(tau, y) 
// Note:  y(1)=theta, y(2)=d(theta)/dtau
    dy_dtau(1)=y(2),    // this is d(theta)/dtau     
    dy_dtau(2)=(3*(1+L2_over_L1)*(Mbar_over_mgL1 -cstar*y(2)) -3*( 1+2*L2_over_L1 -xdoubledot_over_g*L2_over_L1^2 )*sin(y(1))/2 -3*( L2_over_L1^2 +xdoubledot_over_g*(1+2*L2_over_L1) )*cos(y(1))/2 )/(1+3*L2_over_L1+L2_over_L1^3)  
// dy_dtau(2) is d2(theta)/dtau2 from Eq. (5.3.11c) 
endfunction

initial_conditions=[theta_0; thetaprime_0];
theta_and_dthetadtau=ode(initial_conditions, 0, tau, rhs_of_diff_eqs), 

output=[tau', theta_and_dthetadtau']    // ' is the transpose operator
// The variable output is a n by 3 matrix, where n is the number of points in the array tau
// column 1: tau, column 2: theta, column 3: d(theta)/dtau  

xdel(winsid( ))  // deleting all existing figures before plotting theta versus tau
figure('background', 8);   plot(tau, theta_and_dthetadtau(1,:)*180/%pi),   xgrid
xlabel(['Normalized time ', '$\tau$'], 'fontsize', 3) 
ylabel(['$\theta$', ' (degrees)'], 'fontsize', 3),   title('Example 5.3.11','fontsize', 3)

// ANIMATION (distances are normalized by L1): 
  len=length(tau)  
  theta=output(:,2),  sin_theta=sin(theta), cos_theta=cos(theta) 
  xA=zeros(len,1) , yA=xA,   xB=sin_theta,  yB=-cos_theta  
 // The seven variabled defined aboove are len by one columns
  xD=xB+L2_over_L1*cos_theta,  yD= L2_over_L1*sin_theta-cos_theta
  x_coordinates=[xA, xB, xD]; y_coordinates=[yA, yB, yD]; 
  animate_nbars(x_coordinates, y_coordinates)    // this call animates the motion
endfunction     // end of the file sim_model_ex5_3_11.sci
