function output = sim_model_ex5_3_13(t, k_factor, c1_star, c2_star, phi_0, phidot_0, theta_0, thetadot_0)
// Example 5.3.13 (t here is actually the normalized time tau),
// Example of usage ( using the initial conditions  
//      phi_0=20*%pi/180; phidot_0=0; theta_0=32*%pi/180; thetadot_0=50 ): 
// my_output = sim_model_ex5_3_13([0:0.005:50], 12, 0.1, 0.1, 20*%pi/180, 0, 32*%pi/180, 50);

disp('The k_factor is 12*(1+m1/(3*m2)/[(b/L)^2+(h/L)^2)]')
disp('Change it, if desired, to any other appropriate value')
disp('NOTE: IN ADDITION TO ANIMATING THE SYSTEM ANALYZED IN EXAMPLE 5.3.13,')
disp('AND PLOTTING phi AND theta versus time, A CALL TO THE FUNCTION sim_model_ex5_3_13,')  
disp(' AS EXEMPLIFIED IN THE FIRST 4 COMMENT LINES OF THIS FUNCTION,') 
disp(' RETURNS 5 COLUMNS CONTAINING  t, phi, d(phi)/dtau, theta, and d(theta)/dtau')
disp(' PLOTS CAN THE BE DONE USING THE plot COMMAND')

function dy_dt=rhs_of_diff_eqs(t, y) 
// Note:  y(1)=phi, y(2)=d(phi)/dt, y(3)=theta, y(4)=d(theta)/dt  
    dy_dt(1)=y(2),    // this is d(phi)/dt and the next one is d2(phi)/dt2 from Eq. (5.3.13j)    
    dy_dt(2)= -sin(y(1))-c1_star*y(2)-c2_star*(y(2)+y(4)) 
    dy_dt(3)=y(4)
    dy_dt(4)= -k_factor*c2_star*(y(2)+y(4))   // this is from Eq. (5.3.13k)
endfunction

initial_conditions=[phi_0; phidot_0; theta_0; thetadot_0]
state_variables=ode(initial_conditions, 0, t, rhs_of_diff_eqs) 
output=[t', state_variables']  
// The variable output is a n by 5 matrix, where n is the number of points in the array t
// column 1: t, column 2: phi, column 3: d(phi)/dt;  column 4: theta, column 5: d(theta)/dt
phi=output(:,2) ,  theta=output(:,4)

xdel(winsid( )) // deleting all existing figures 
figure('background', 8); plot(t', phi*180/%pi),   xgrid   //  plot of phi (in degrees) versus tau
xlabel(['Nondimensional time', '$\tau$'], 'fontsize', 3) 
ylabel(['$\phi$', ' (degrees)'], 'fontsize',3),  title('Example 5.3.13','fontsize', 3)

figure('background', 8);    plot(t', theta*180/%pi),   xgrid  // plot of theta (in deg) versus tau 
xlabel(['Nondimensional time', '$\tau$'], 'fontsize', 3)
ylabel(['$\theta$', ' (degrees)'], 'fontsize',3),  title('Example 5.3.13','fontsize', 3)

// ANIMATION (distances are normalized by L): 
  len=length(t),  // this is the number of time occurrences in the given len by 1 row matrix t  
  col_of_zeros=zeros(len,1),   // this is a len by 1 column of zeros
  sin_phi=sin(phi), cos_phi=cos(phi),  sin_theta=sin(theta), cos_theta=cos(theta)    
  xO=col_of_zeros, yO=xO,      xC2=sin_phi,  yC2=-cos_phi   
  xN=xC2+0.25*sin_theta,  yN= yC2+0.25*cos_theta 
  xM=xC2-0.25*sin_theta,  yM= yC2-0.25*cos_theta  
  x_coordinates=[xO, xC2, xN, xM];  y_coordinates=[yO, yC2, yN, yM]
  animate_nbars(x_coordinates, y_coordinates)
endfunction     // end of the file sim_model_ex5_3_13.sci
