function output=top_dynamics(t, Iz_over_In, mgL_over_In, phidot_0, psidot_0, theta_0, thetadot_0)
// Top dynamics analyzed in Section 6.6.3
// Example of usage ( using the initial conditions  
//         phidot(0)=5.03; psidot(0)=45.65; theta(0)=%pi/6; thetadot(0)=0 ): 
// my_output = top_dynamics([0:0.002:10], 27/68, 27*98.1/34, 5.03, 45.65, 30*%pi/180, 0);

disp('NOTE: IN ADDITION TO ANIMATING THE MOTION OF THE TOP, A CALL SUCH AS ')
disp(' output = top_dynamics([0:0.025:10], 27/68, 27*98.1/34,  5.03, 45.65, 30*%pi/180, 0);') 
disp('RETURNS, IN THE VARIABLE output, 4 COLUMNS CONTAINING  t, phi, theta, dtheta_dt')
disp('')

function dy_dt=rhs_of_diff_eqs(t, y) 
// y(1)=phi, y(2)=theta, y(3)=d(theta)/dt 
    cos_theta0=cos(theta_0), sin_theta0=sin(theta_0), sin_theta=sin(y(2)), cos_theta=cos(y(2))
    omegaz = psidot_0+phidot_0*cos_theta0 
    Hz0_over_In = phidot_0*(sin_theta0^2)+Iz_over_In*omegaz*cos_theta0
    dy_dt(1)= (Hz0_over_In - Iz_over_In*omegaz*cos_theta)/(sin_theta^2) // this is d(phi)/dt
    dy_dt(2)=y(3),    // this is d(theta)/dt and the one that folllows is d2(theta)/dt2 
    dy_dt(3)=(mgL_over_In + (dy_dt(1)*cos_theta - Iz_over_In*omegaz)*dy_dt(1) )*sin_theta
endfunction

phi_0=0;  phi_theta_thetadot=ode([phi_0; theta_0; thetadot_0], 0, t, rhs_of_diff_eqs) 
output=[t', phi_theta_thetadot']   
phi=output(:,2), theta=output(:,3),   sin_theta=sin(theta)    

xdel(winsid())  // deleting all existing figures
// Plot of phi (in degrees) versus time
  figure('background', 8)    // 'background' 8 forces the figure background to be white  
  plot(t', phi*180/%pi),   xgrid  // plot of phi (in degrees) versus time t
  xlabel('t  (seconds)', 'fontsize', 3), ylabel(['$\phi$',  '(degrees)'], 'fontsize', 3) 

// Plot of theta (in degrees) versus time
  figure('background', 8),  plot(t', theta*180/%pi),   xgrid   
  xlabel('t  (seconds)', 'fontsize', 3), ylabel(['$\theta$',  '(degrees)'], 'fontsize', 3)  

// ANIMATION:  
  len=length(t)   // number of points in the given array t 
  xO=zeros(len,1), yO=xO, zO=xO   // these are columns of zeros
  xC=sin_theta.*cos(phi),  yC=sin_theta.*sin(phi),  zC=cos(theta)
  x_coordinates=[xO, xC], y_coordinates=[yO, yC], z_coordinates=[zO, zC]  
  animate3d_nbars(x_coordinates, y_coordinates, z_coordinates)
endfunction      // end of the file top_dynamics.sci
